function [trackLines, alpha] = getTracks(subset, imgBW, imgGray, trackGeom, GSD, p)

    % Funktion
    %   Detektion geradliniger Strukturen mit anschlieender Identifikation
    %   und Korrektur der Fahrgassenlinien.
    % 
    % Eingabe
    %   - subset:           Subset-ID
    %   - imgBW:            Binres Kantenbild
    %   - imgGray:          Grauwertbild
    %   - trackGeom:        Parameter des Fahrspurmodells
    %   - GSD:              Bodenauflsung
    %   - p:                Flag zum Plotten (1 = ja, 0 = nein)
    %
    % Ausgabe
    %   - trackLines:       Fahrgassenlinien
    %   - alpha:            Winkel der Vorzugsrichtung    
             
    disp('Detektion der gesuchten Strukturen')
    tic

    % (1) Hough-Transformation --------------------------------------------
    numTracks       = 16;
    houghLines      = getHoughLines(imgBW, numTracks);

    if(p)
        figure
        ax(1) = subplot(1,3, 1);
        imagesc(imgBW), axis image, colormap gray, hold on, title('Ergebnis der Hough-Transformation')
        for k = 1:length(houghLines)
            xy = [houghLines(k).point1; houghLines(k).point2];
            plot(xy(:,1),xy(:,2),'LineWidth',3,'Color',[28,134,238]./255);
        end      
    end    
    
    % (2) Filterung der Linien in Vorzugsrichtung ------------------------
    [trackLines, alpha]     = removeNoPrefLines(houghLines);
    midLineDist             = getMidLineDist(trackLines);
    
    if(p)
        ax(2) = subplot(1,3, 2);
        imagesc(imgBW), axis image off, colormap gray, title('Linien in Vorzugsrichtung'), hold on
        for k = 1:length(trackLines)    
            xy = [trackLines(k).point1; trackLines(k).point2];
            plot(xy(:,1),xy(:,2),'LineWidth',2,'Color', [28,134,238]./255);    
        end       
    end    
    
    % (3) Approximation der Fahrgassen -----------------------------------
    trackLines0 = approxLines(trackLines, imgBW, trackGeom, GSD, 0);   
   
    % (4) Korrektur der approximierten Hough-Linien ----------------------
    %       (und erneute Approximation)
    trackLines     = correctLines(trackLines0, imgGray, subset);
    trackLines     = approxLines(trackLines, imgBW, trackGeom, GSD, 1);    
    
    if(p)
        ax(3) = subplot(1, 3, 3);
        imagesc(imgBW), axis image off, colormap gray, hold on, title('Korrektur der Linien')
        for k = 1:length(trackLines0)    
            xy = [trackLines0(k).point1; trackLines0(k).point2];
            plot(xy(:,1),xy(:,2),'LineWidth',3,'Color',[28,134,238]./255);    
        end
        for k = 1:length(trackLines)    
            xy = [trackLines(k).point1; trackLines(k).point2];
            plot(xy(:,1),xy(:,2),'LineWidth',3,'Color','g');
        end
        linkaxes(ax,'xy'); 
    end
    toc
end