function [xyEndings] = peakAnalysis(lineDeriv, lineVals, lineValsMid)

    % Funktion
    %   Extremwertanalyse des Grauwertprofils einer Fahrgassenlinie anhand
    %   statistischer Kennwerte und Ermittlung neuer Linienendpunkte.
    % 
    % Eingabe
    %   - lineDeriv:       Erste Ableitung des mittleren Grauwertprofils
    %   - lineVals:        Grauwertprofil
    %   - lineValsMid:     Mittleres Grauwertprofil
    %
    % Ausgabe
    %   - xyEndings:       Korrigierte Linienendpunkte

    % Extremwerte der ersten Ableitung -----------------------------------
    [pksMax,locsMax] = findpeaks(lineDeriv);
    [pksMin,locsMin] = findpeaks(-1.*lineDeriv);
    allPks           = [pksMax locsMax; (-1.*pksMin) locsMin; ...
                        lineDeriv(1) 1; lineDeriv(end) length(lineDeriv)];   
    allPksSort       = sortrows(allPks, 2);        
    pks              = allPksSort(:, 1);
    locs             = allPksSort(:, 2);
    
    % Statistische Kennwerte ---------------------------------------------
    mid = mean(pks(2:end-1));
    s   = std(pks(2:end-1));

    % Analyse der Extremwerte --------------------------------------------
    meanPks = [];
    for i=1:length(pks)-1
        if(abs(pks(i)-pks(i+1)) > s)
            meanPks = [meanPks; pks(i) locs(i) i; pks(i+1) locs(i+1) i+1];                
        end
    end        
    meanPks = unique(meanPks,'rows');
    meanPks = sortrows(meanPks, 2);    

    % Bestimmung der innen liegenden meanPks -----------------------------
    dbp     = diff(meanPks(:, 2));
    [M I]   = max(dbp);    
    IDX1    = meanPks(I, 2);        % Index fr lineVals
    IDX2    = meanPks(I+1, 2);
    idxL1   = meanPks(I, 3);        % Index fr locs
    idxL2   = meanPks(I+1, 3);
    
    % Bestimmung der neuen Linien-Endpunkte ------------------------------
    xyStart = lineVals(IDX1, 2:3);
    xyStop  = lineVals(IDX2, 2:3);
                    
    % Anpassung der Grauwertdifferenz der neuen Endpunkte ----------------
    gray    = [lineValsMid(locs(idxL1)) lineValsMid(locs(idxL2))];
    
    % Grauwertdifferenz
    delta    = abs(gray(1)-gray(2));
    
    % Anpassung falls, Differenz ber der Standardabweichung
    if(delta > s)
        [minG idxG] = min(gray);
        m = 1; step = 0;
        % Anpassung des Endpunktes mit dem niedrigeren Grauwert
        if(idxG == 1)
            % Startpunkt wird angepasst 
            refVal = lineValsMid(locs(idxL2));
            while(m)
                step    = step + 1;
                curVal = lineValsMid(locs(idxL1+step));
                if(abs(curVal-refVal) <= s)
                    m = 0;
                    xyStart = lineVals(locs(idxL1+step), 2:3);
                end
            end
        else
            % Endpunkt wird angepasst
            refVal = lineValsMid(locs(idxL1));
            while(m)
                step    = step - 1;
                curVal = lineValsMid(locs(idxL2+step));
                if(abs(curVal-refVal) <= s)
                    m = 0;
                    xyStop = lineVals(locs(idxL2+step), 2:3);
                end
            end
        end
    end   
    
    xyEndings = [xyStart; xyStop];            
   
end