function [imgTrackArea, tracks] = geomAnalysis(data, trackLines, trackGeom, GSD, S, a, p)

    % Funktion
    %   Flchenabschtzung fr alle Fahrgassenpixel anhand eines
    %   Fahrspurmodells mit Angaben zur
    %           - Fahrspurbreite t1
    %           - Fahrgassenbreite t2 und
    %           - Fahrgassenabstand t3.
    %   Die Ausgangsdaten werden um den Faktor S skaliert, um 
    %   Subpixel-Genauigkeit zu erreichen. Die Flchenberechnung erfolgt 
    %   anhand der Schnittpunkte aus der Verschneidung der Pixel- mit der 
    %   Fahrspurgeometrie. 
    % 
    % Eingabe
    %   - data:             Hyperspektraldaten
    %   - trackLines:       Fahrgassenlinien
    %   - trackGeom:        Parameter des Fahrspurmodells
    %   - GSD:              Bodenauflsung
    %   - S:                Skalierungsfaktor
    %   - a:                Winkel der Vorzugsrichtung
    %   - p:                Flag zum Plotten (1 = ja, 0 = nein)
    %
    % Ausgabe
    %   - imgTrackArea:     Matrix der Flchenabschtzung
    %   - tracks:           Modellierte Fahrspurlinien
    
    disp('Abschtzung der Abundanzen')
    tic

    % berfhrung und Skalierung der metrischen Gren -------------------
    t1      = (trackGeom(1)*S)/GSD;
    t2      = (trackGeom(2)*S)/GSD;
    APix    = S^2;

    % Skalierung der Ausgangs-Matrix -------------------------------------
    [lines, samples, bands] = size(data);
    imgTrackArea            = zeros(lines, samples, 2);
    imgB                    = zeros(S*lines, S*samples);
    [height, width]         = size(imgB);   
    
    % Modellierung und Skalierung der Fahrspurlinien ---------------------
    tracks  = getScaledTracks(trackLines, S, t1, t2);

    if(p)
        figure(6)
        imagesc(imgB(:, :, 1)), axis image, colormap gray, hold on
        for kk = 1:length(tracks) 
            xy = [tracks(kk).point1; tracks(kk).point2];
            plot(xy(:,1),xy(:,2),'LineWidth',3,'Color','green'); 
        end
        for kk = 1:length(trackLines) 
            xy = [S*trackLines(kk).point1-5; S*trackLines(kk).point2-5];
            plot(xy(:,1),xy(:,2),'LineWidth',3,'Color','blue'); 
        end
    end   
    
    % Verschneidung aller "Pixel-Quadrate" mit allen Fahrspurlinien ------
    xx = 0; yy = 0;
    for y=1:S:height
        yy = yy +1;
        for x=1:S:width    
            xx = xx +1;
            
            A = 0; sf = 0;

            % Aktuelles "Pixel-Quadrat"
            rect    = [x y S-1 S-1]; % [x0 y0 width height]
            xyRect  = [x y; x+S-1 y; x+S-1 y+S-1; x y+S-1];% alle Eckpunkte
            if(p)
                rectangle('Position',rect, 'EdgeColor','red','LineWidth',2)
            end

            % Schnittpunktberechnung -------------------------------------        
            intPoints = [];
            for k = 1:length(tracks)                
                interXY     = interLineRect(tracks(k), rect, k);
                intPoints   = [intPoints; interXY];
            end

            % Auswertung der Schnittpunkte -------------------------------            
            % (1) Einzelne Schnittpunkte werden entfernt
            if(size(intPoints, 1)==1)
                intPoints(1, :) = []; 
            end
            
            if(~isempty(intPoints))     
                % (2) Entfernung ungltiger Schnittpunkte
                intPoints = adaptIntPoints(intPoints);               
                
                if(isempty(intPoints))
                    sf = 1;                    

                % (3) Flchenberechnung mit Fallunterscheidung
                elseif(size(intPoints, 1) == 1)
                    sf = 1;
                    
                elseif(size(intPoints, 1) == 2) % -- 2 Schnittpunkte -----
                    % Eckpunkt?
                    [Lia, Locb] = ismember(intPoints(:, 1:2), xyRect, 'rows');
                    if(isempty(find(Lia)))
                        % Check: Punkte auf einer Rechteck-Kante? 
                        if(intPoints(1, 3) == intPoints(2, 3))
                            % Berechnung des nhsten Eckpunktes
                            incCorner = getCorner(intPoints, xyRect);                 
                            intPoints = [intPoints; incCorner];
                            % Sortierung im Uhrzeigersinn 
                            [intPoints] = sortClockwise(intPoints);  
                            % Flchenberechnung
                            A   = polyarea(intPoints(:, 1),intPoints(:, 2))/APix;
                        else
                            sf = 1;
                        end
                    else
                        sf = 1;
                    end
                
                elseif(size(intPoints, 1) == 3) % -- 3 Schnittpunkte -----
                    xPos = unique(intPoints(:, 2));
                    if(length(xPos) <= 2)
                        % Punkte liegen auf einer Kante
                        sf = 1;
                    end

                elseif(size(intPoints, 1) == 4) % -- 4 Schnittpunkte -----
                    % Anpassung des Polygons
                    intPoints = checkForCorners(intPoints, xyRect, rect, a);
                    intPoints = sortrows(intPoints, 3);         
                    % Sortierung im Uhrzeigersinn 
                    [intPoints] = sortClockwise(intPoints);                    
                    % Flchenberechnung            
                    A   = polyarea(intPoints(:, 1),intPoints(:, 2))/APix;                 

                elseif(size(intPoints, 1) == 6) % -- 6 Schnittpunkte -----
                    % Separation der Flchen
                    [part1, part2] = getAreaSegments6(intPoints, xyRect, rect, a);
                    % Sortierung im Uhrzeigersinn    
                    [part1] = sortClockwise(part1);
                    [part2] = sortClockwise(part2);
                    % Flchenberechnung
                    A1   = polyarea(part1(:, 1),part1(:, 2));
                    A2   = polyarea(part2(:, 1),part2(:, 2));
                    A    = (A1 + A2)/APix;

                elseif(size(intPoints, 1)== 8) % -- 8 Schnittpunkte ------
                    % Separation der Flchen
                    [part1, part2] = getAreaSegments8(intPoints, xyRect, ... 
                                        rect, tracks, a);
                    % Sortierung im Uhrzeigersinn
                    [part1] = sortClockwise(part1);
                    [part2] = sortClockwise(part2);
                    % Flchenberechnung
                    A1   = polyarea(part1(:, 1),part1(:, 2));
                    A2   = polyarea(part2(:, 1),part2(:, 2));
                    A    = (A1 + A2)/APix;
                    
                else
                    disp('Achtung: Keine Flchenberechnung')
                    x, y
                end
                
                if(p)
                    for i=1:size(intPoints, 1)
                        iXY = intPoints(i, :);
                        plot(iXY(1), iXY(2),'x','Linewidth', 3, 'Color','r'), hold on
                    end
                end
                    
                if(A == 0 && sf == 0), A, x, y, pause, end
                
            end
            
            % Ergebnismatrix mit Flcheninhalt pro Pixel -----------------
            if(A ~= 0)
                imgTrackArea(yy, xx, 1) = A;
                imgTrackArea(yy, xx, 2) = intPoints(1, 5); 
            end
           
        end
        xx = 0;
    end
    toc
end

