function [imgVeg, imgTrack] = getRefPlantSpec(data, trackLines, imgTrackArea, RGB, trackGeom, GSD, WL, p)

    % Funktion
    %   Bestimmung der Bestandsreferenzspektren fr jedes identifizierte
    %   Fahrgassenpixel mit Hilfe benachbarter purer Bestandspixel. 
    % 
    % Eingabe
    %   - data:             Hyperspektraldaten
    %   - trackLines:       Fahrgassenlinien
    %   - imgTrackArea:     Matrix der Flchenabschtzung
    %   - RGB:              RGB-Darstellung des Subset
    %   - trackGeom:        Parameter des Fahrspurmodells
    %   - GSD:              Bodenauflsung
    %   - WL:               Wellenlngen der Spektralbnder
    %   - p:                Flag zum Plotten (1 = ja, 0 = nein)
    %
    % Ausgabe
    %   - imgVeg:           Matrix der Bestandsreferenzspektren
    %   - imgTrack:         Matrix der Flchenabschtzung

    disp('Ermittlung des Bestandsreferenzsignals')
    tic

    [lines, samples, bands]     = size(data);
    imgVeg                      = zeros(lines, samples, bands);
    imgTrack                    = zeros(lines, samples);
        
    % Mittlerer Abstand zur Vegetation -----------------------------------
    midLineDist = getMidLineDist(trackLines);
    if(mod(midLineDist, 2) == 0)
        % gerade Anzahl
        vd = (midLineDist)/2-1;
    else
        % ungerade Anzahl
        vd = (midLineDist-1)/2;
    end   

    % Bestimmung der uersten Hough-Linien ------------------------------
    paramList   = getParamList(trackLines);
    PL1         = sortrows(paramList, 7);
    excLines    = [PL1(1, 1),  PL1(end, 1)];    

    % Verarbeitung pro Linie ---------------------------------------------
    for k=1:length(trackLines)
        if(p)
            figure(2)
            imagesc(RGB), axis image, colormap gray, hold on, title(['Linie ' num2str(k)])
            xy = [trackLines(k).point1; trackLines(k).point2];
            plot(xy(:,1),xy(:,2),'LineWidth',2,'Color','r'); 
        end
        
        % Linienparameter
        theta0  = trackLines(k).theta;
        theta   = 90 - theta0;
        
        % Abstand zum gesuchten Bestandspixel
        DX = vd*sind(theta);
        DY = vd*cosd(theta);
        
        % Bildsegment pro Linie
        imgP    = (imgTrackArea(:, :, 2) == k);
        indices = find(imgP(:));        
        [Y,X]   = ind2sub([lines, samples],indices);        
        imgPP   = imgP(round(min(Y)):round(max(Y)), round(min(X)):round(max(X)));   
                 
        % Definition der Pixelumgebung
        estTrackWidth   = ceil(trackGeom(2)/GSD);
        mask            = getMask(midLineDist, theta, estTrackWidth);
        
        
        % Festlegung der zu bersksichtigenden Bestandsseiten
        [s1, s2, step]  = getLoopParams(excLines, k);
        
        % Verarbeitung aller dazugehrigen Pixel
        lineVals = [];   

        for i=1:size(imgPP, 1)
            for j=1:size(imgPP, 2)              
                if(imgPP(i, j) ~= 0)                    % Zugerhriges Fahrgassenpixel 
                    veg = [min(Y)+i-1 min(X)+j-1];                                       
                    novp = 0; sumSpec = 0;
                    
                    % Detektion der Bestandspixel
                    for m=s1:step:s2                        
                        curVeg = round(veg + m*[DY DX]);
                        
                       % Analyse der Pixelumgebung
                       [outlier, pixSpec] = analyzePixEnv(data, curVeg, WL, mask, 0);                       
                       if(~outlier)
                           sumSpec  = sumSpec + pixSpec;
                           novp     = novp +1;                           
                       end
                       
                       if(p), plot(curVeg(2), curVeg(1), 's', 'LineWidth',5, 'Color', 'g'), end
                       
                       % Rotation der Pixelumgebung 
                       mask        = imrotate(mask, 180);
                    end
                    
                    % Befllen der Ergebnismatrix ------------------------
                    if(novp == 0)
                        % Indizierung einer Lcke
                        imgVeg(veg(1), veg(2), :) = 0;                        
                        if(p), plot(veg(2), veg(1), 'x', 'LineWidth',3, 'Color', 'b'), end
                        lineVals = [lineVals; veg -1];
                    else
                        % Mittelung der Spektren
                        midSpec                     = sumSpec/novp;
                        imgVeg(veg(1), veg(2), :)   = midSpec;
                        lineVals                    = [lineVals; veg 1];
                    end   
                    imgTrack(veg(1), veg(2)) = imgTrackArea(veg(1), veg(2), 1);
                end
            end
        end

        % Interpolation fehlender Stellen --------------------------------
        missingPixIdx = find(lineVals(:, end)<0);
        if(~isempty(missingPixIdx))
            [imgVeg, imgTrack] = interpolateGaps(lineVals, missingPixIdx, imgVeg, imgTrack);     
        end
        
        if(p), pause, end
    end    
    toc
end