function [imgSoil] = getSoilSpec(data, imgVeg, imgTrackArea, opt, N, p)

    % Funktion
    %   Ableitung des Bodenspektrums fr jedes identifizierte
    %   Fahrgassenpixel. Es wird zwischen zwei Optimierungsverfahren
    %   unterschieden: nonlinearOpt und linearOpt.
    % 
    % Eingabe
    %   - data:             Hyperspektraldaten
    %   - imgVeg:           Matrix der Bestandsreferenzspektren
    %   - imgTrackArea:     Matrix der Flchenabschtzung
    %   - opt:              ID des Optimierungsverfahrens 
    %                       (1 = linear, 2 = nonlinear)
    %   - p:                Flag zum Plotten (1 = ja, 0 = nein)
    %
    % Ausgabe
    %   - imgSoil:          Matrix der Bodenspektren

    disp('Ableitung des Bodensignals')
    tic

    [lines, samples, bands]     = size(data);
    imgSoil                     = zeros(lines, samples, bands); 
        
    % Ergebnis der Flchenabschtzung
    imgA0   = imgTrackArea(:, :, 2);
    imgA2   = imgTrackArea(:, :, 1);
    imgA1   = 1-imgA2;
    
    % Verarbeitung pro Fahrgasse -----------------------------------------
     for k=1:max(imgA0(:))
        
        % Bildsegment pro Linie
        imgP    = (imgTrackArea(:, :, 2) == k);
        indices = find(imgP(:));        
        [Y,X]   = ind2sub([lines, samples],indices);
        imgPP   = imgP(min(Y):max(Y), min(X):max(X));       
        
        % Verarbeitung aller dazugehrigen Pixel
        pixNum = 0; XY = [];
        RM = []; E1 = []; a = [];
        
        % Auslesen der Linien-Parameter ----------------------------------
        for i=1:size(imgPP, 1)
            for j=1:size(imgPP, 2)                
                if(imgPP(i, j) ~= 0)                    
                    pixNum = pixNum +1;                    
                    % Koordinaten im Ausgangsbild
                    x0  = min(X)+j-1;
                    y0  = min(Y)+i-1;
                    XY  = [XY; y0 x0];                    
                    % Flchen
                    a   = [a imgA1(y0, x0)];                    
                    % Pixelspektren
                    rv  = squeeze(data(y0, x0, :));
                    RM   = [RM rv./100];                    
                    % Vegetationsspektren
                    e1v = squeeze(imgVeg(y0, x0, :));
                    E1  = [E1 e1v./100];                     
                end
            end
        end
                
        % Berechnung der Bodenspektren -----------------------------------        
        if(opt == 1) % Optimierungsansatz 1
            [imgSoil] = linearOpt(imgSoil, XY, a, RM, E1, N);
        elseif(opt == 2) % Optimierungsansatz 2
            noi = 200;
            [imgSoil] = nonlinearOpt(imgSoil, XY, a, RM, N, noi);
        end         
                
        if(p)            
            figure(1)
            imagesc(imgSoil(:, :, 1)), axis image
            pause
        end
        
     end
    toc
end