function [imgSoil] = linearOpt(imgSoil, XY, a, RM, E1, N)

    % Funktion
    %   Bestimmung der Bodenspektren anhand eines linearen
    %   Optimierungsverfahrens, wobei die gesuchten Spektren jeweils an ein 
    %   lokales mittleres Bodenspektrum angenhert werden. Dieses mittlere
    %   Bodenspektrum berechnet sich aus der Betrachtung eines
    %   Spektramodells bestehend aus N aufeinanderfolgenden
    %   Fahrgassenpixeln.
    % 
    % Eingabe
    %   - imgSoil:      Matrix der Bodenspektren
    %   - XY:           Pixelkoordinaten der Fahrgassenpixel des Spektralmodells
    %   - a:            Vektor der Bestandsflchen des Spektralmodells
    %   - RM:           Matrix der Pixelspektren des Spektralmodells
    %   - E1:           Matrix der Bestandsreferenzspektren des Spektralmodells
    %   - N:            Anzahl der Pixel im betrachteten Spektralmodell
    %
    % Ausgabe
    %   - imgSoil:      Matrix der Bodenspektren

    % Modellparameter
    lam     = 0.03;
    N       = (N-1)/2;

    for k=1+N:length(XY)-N
        
        % Definition des Spektralmodells
        a_m     = a(k-N:k+N);
        R_m     = RM(:, k-N:k+N);
        E1_m    = E1(:, k-N:k+N);
        
        % Parameter des aktuellen Fahrgassenpixels
        a1      = a(k);
        e1v     = E1(:, k);
        rv      = RM(:, k);
        
        % Mittleres Bodenspektrum
        e2v_m   = getMidSoilSpec(a_m, R_m, E1_m);
                
        % Schtzung des Bodenspektrums
        e2      = ((1-a1)*(rv - a1*e1v) + lam*e2v_m)/((1-a1)^2 + lam);

        % Positivitt
        e2(e2<0)= 0;

        % Ergebnismatrix      
        imgSoil(XY(k, 1), XY(k, 2), :) = e2;       

    end
end