function [imgSoil] = nonlinearOpt(imgSoil, XY, a00, RM, N, noi)

    % Funktion
    %   Bestimmung der Bodenspektren anhand eines nicht-linearen
    %   Optimierungsverfahrens, bei dem das Bodenspektrum und die
    %   Flchenanteile des Pflanzenbestands abwechselnd in einem
    %   Iterationsprozess geschtzt werden. Dies erfolgt durch die
    %   Betrachtung eines Spektralmodells von N aufeinanderfolgenden 
    %   Fahrgassenpixeln.
    %
    % Eingabe
    %   - imgSoil:      Matrix der Bodenspektren
    %   - XY:           Pixelkoordinaten der Fahrgassenpixel des Spektralmodells
    %   - a00:          Vektor der Bestandsflchen des Spektralmodells
    %   - RM:           Matrix der Pixelspektren des Spektralmodells
    %   - N:            Anzahl der Pixel im betrachteten Spektralmodell
    %   - noi:          Anzahl der Iterationen
    %
    % Ausgabe
    %   - imgSoil:      Matrix der Bodenspektren

    % Modellparameter
    n       = size(RM, 1);
    N       = (N-1)/2;
    b       = ones(n,1)*10';
    mu_a    = 1000;
    mu_e    = 0.01;
    eins    = [0;1];    

    for k=1+N:length(XY)-N
        
        % Definition des Spektralmodells
        a0  = a00(k-N:k+N);
        R   = RM(:, k-N:k+N);
        A0  = [a0; ones(size(a0))];
        A   = A0;       
        aE  = a0';
        
        % Iteration
        for j=1:noi
            % (1) Schtzung von E    
            E   = ((A*A'+mu_e*eins*eins')\(A*R'+mu_e*eins*b'))';

            % Differenzenvektor
            d   = E(:,1);
            e2  = E(:,2);
            e1  = d+e2;

            % Positivittsbedingung
            e2  = e2.*(e2>0);
            e1  = e1.*(e1>0);

            % Differenzenvektor
            d   = e1-e2;

            % (2) Schtzung von a
            a  = (d'*d+mu_a)\(d'*(R-e2*ones(size(a0)))+mu_a*aE');

            % Matrix A
            A = [a; ones(size(a0))];
            
        end
        
        e2  = E(:,2);
        e2  = e2.*(e2>0);

        % Ergebnismatrix
        imgSoil(XY(k, 1), XY(k, 2), :) = e2;
                
    end    
end
